import psycopg2


class Database:
    def __init__(self, creds):
        keys = ['host', 'port', 'name', 'user', 'pass']
        for key in keys:
            if not key in creds:
                raise ValueError(f'missing cred key={key}')
        self.creds = creds
        self.conn = None
        self.queued = []

    def _connstr_(self):
        connstr = f"host={self.creds['host']} port={self.creds['port']} "
        connstr += f"dbname={self.creds['name']} user={self.creds['user']} "
        connstr += f"password={self.creds['pass']}"
        return connstr

    def close(self):
        if self.conn:
            self.conn.close()
            self.conn = None

    def connect(self):
        if self.conn:
            self.close()
        self.conn = psycopg2.connect(self._connstr_())

    def store(self, reading):
        try:
            if not self.conn:
                self.connect()
            cur = self.conn.cursor()

            cur.execute("""INSERT INTO readings
        (created, temp, press, humid)
        VALUES (%s, %s, %s, %s)
        """, (reading.time.timestamp(), reading.temp, reading.press, reading.hum))
            self.conn.commit()
            cur.close()

            if len(self.queued) > 0:
                self.store(self.queued.pop())
        except:
            print('db error')
            self.queued.append(reading)
